@@ -49,6 +49,29 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateSavingPlanOrder(self, request):
+        """创建节省计划订单，创建订单完成需调用PayDeals接口完成订单支付
+
+        :param request: Request instance for CreateSavingPlanOrder.
+        :type request: :class:`tencentcloud.billing.v20180709.models.CreateSavingPlanOrderRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.CreateSavingPlanOrderResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSavingPlanOrder", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateSavingPlanOrderResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAllocationTag(self, request):
         """批量取消设置分账标签
 
@@ -96,7 +119,7 @@ class BillingClient(AbstractClient):
 
 
     def DescribeBillDetail(self, request):
-        """查询账单明细数据。
+        """获取账单明细数据。
         注意事项：
         1.在请求接口时，由于网络不稳定或其它异常，可能会导致请求失败。如果您遇到这种情况，我们建议您在接口请求失败时，手动发起重试操作，这样可以更好地确保您的接口请求能够成功执行。
         2.对于账单明细数据量级很大（例如每月账单明细量级超过20w）的客户，通过 API 调用账单数据效率较低，建议您开通账单数据存储功能，通过存储桶中获取账单文件进行分析。[账单存储至COS桶](https://cloud.tencent.com/document/product/555/61275)
@@ -121,6 +144,53 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBillDetailForOrganization(self, request):
+        """成员账号获取管理账号代付账单（费用明细）。
+        注意事项：在请求接口时，由于网络不稳定或其它异常，可能会导致请求失败。如果您遇到这种情况，我们建议您在接口请求失败时，手动发起重试操作，这样可以更好地确保您的接口请求能够成功执行。
+
+        :param request: Request instance for DescribeBillDetailForOrganization.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeBillDetailForOrganizationRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeBillDetailForOrganizationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBillDetailForOrganization", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBillDetailForOrganizationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeBillDownloadUrl(self, request):
+        """该接口支持通过传参，获取L0-PDF、L1-汇总、L2-资源、L3-明细、账单包、五类账单文件下载链接
+
+        :param request: Request instance for DescribeBillDownloadUrl.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeBillDownloadUrlRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeBillDownloadUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBillDownloadUrl", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBillDownloadUrlResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeBillList(self, request):
         """获取收支明细列表，支持翻页和参数过滤
 
@@ -145,7 +215,7 @@ class BillingClient(AbstractClient):
 
 
     def DescribeBillResourceSummary(self, request):
-        """查询账单资源汇总数据
+        """获取账单资源汇总数据
 
         :param request: Request instance for DescribeBillResourceSummary.
         :type request: :class:`tencentcloud.billing.v20180709.models.DescribeBillResourceSummaryRequest`
@@ -167,6 +237,29 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBillResourceSummaryForOrganization(self, request):
+        """成员账号获取管理账号代付账单（按资源汇总）
+
+        :param request: Request instance for DescribeBillResourceSummaryForOrganization.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeBillResourceSummaryForOrganizationRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeBillResourceSummaryForOrganizationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBillResourceSummaryForOrganization", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBillResourceSummaryForOrganizationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeBillSummary(self, request):
         """该接口支持通过传参，按照产品、项目、地域、计费模式和标签五个维度获取账单费用明细。
 
@@ -305,6 +398,29 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBillSummaryForOrganization(self, request):
+        """该接口支持通过传参，按照产品、项目、地域、计费模式和标签五个维度获取账单费用明细。
+
+        :param request: Request instance for DescribeBillSummaryForOrganization.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeBillSummaryForOrganizationRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeBillSummaryForOrganizationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBillSummaryForOrganization", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBillSummaryForOrganizationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeCostDetail(self, request):
         """查询消耗明细
 
@@ -328,6 +444,29 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeCostExplorerSummary(self, request):
+        """查看成本分析明细
+
+        :param request: Request instance for DescribeCostExplorerSummary.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeCostExplorerSummaryRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeCostExplorerSummaryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCostExplorerSummary", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCostExplorerSummaryResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeCostSummaryByProduct(self, request):
         """获取按产品汇总消耗详情
 
@@ -489,6 +628,121 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDosageDetailList(self, request):
+        """获取已接入标准用量明细模板产品的用量明细数据，目前已接入并支持查询的产品包括：云联络中心、实时音视频、实时音视频、智能媒资托管、CODING DevOps、全球IP应用加速
+
+        :param request: Request instance for DescribeDosageDetailList.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeDosageDetailListRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeDosageDetailListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDosageDetailList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDosageDetailListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeSavingPlanCoverage(self, request):
+        """查询当前用户节省计划覆盖率明细数据，如无特别说明，金额单位均为元（国内站）或者美元（国际站）。
+
+        :param request: Request instance for DescribeSavingPlanCoverage.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeSavingPlanCoverageRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeSavingPlanCoverageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSavingPlanCoverage", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSavingPlanCoverageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeSavingPlanOverview(self, request):
+        """查用当前用户明细节省计划总览查询时段内的使用情况
+
+        :param request: Request instance for DescribeSavingPlanOverview.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeSavingPlanOverviewRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeSavingPlanOverviewResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSavingPlanOverview", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSavingPlanOverviewResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeSavingPlanResourceInfo(self, request):
+        """查询节省计划详情
+
+        :param request: Request instance for DescribeSavingPlanResourceInfo.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeSavingPlanResourceInfoRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeSavingPlanResourceInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSavingPlanResourceInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSavingPlanResourceInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeSavingPlanUsage(self, request):
+        """查用当前用户明细节省计划查询时段内的使用情况
+
+        :param request: Request instance for DescribeSavingPlanUsage.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeSavingPlanUsageRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeSavingPlanUsageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSavingPlanUsage", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSavingPlanUsageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeTagList(self, request):
         """获取分账标签
 
